/**
 * Find a least lexicographical match for the longest common subsequence.
 *
 * The returned value is an number array (called `paired`), where the paired[j] indicates that the
 * j-th element of the second sequence is paired with the i-th element of the first sequence.
 *
 * @param N1
 * @param N2
 * @param isEqual
 * @returns
 * @see https://me.guanghechen.com/post/algorithm/lcs/
 */
export declare function findMinLexicographicalLCS(N1: number, N2: number, isEqual: (x: number, y: number) => boolean): number[];
/**
 * Find the length of the longest common subsequence.
 *
 * @param N1
 * @param N2
 * @param isEqual
 * @returns
 * @see https://me.guanghechen.com/post/algorithm/lcs/
 */
export declare function findLengthOfLCS(N1: number, N2: number, isEqual: (x: number, y: number) => boolean): number;
/**
 * Find Longest Common Subsequence with Dynamic Programming.
 *
 * Let dp(i,j) denote the longest common subsequence of {a1,a2,...,ai} and {b1,b2,...,bj}, it is not
 * difficult to derive the transition equation:
 *
 *    dp(i,j) = max{dp(i-1,j), dp(i,j-1), dp(i-1,j-1)+f(i,j)}, where f(i,j) = 1 if ai=aj else 0
 *
 * @param N1
 * @param N2
 * @param isEqual
 * @returns
 * @see https://me.guanghechen.com/post/algorithm/lcs/
 */
export declare function calcDpOfLCS(N1: number, N2: number, isEqual: (x: number, y: number) => boolean): number[][];
